pub struct BatchInputSimplePublicObjectInputForCreate {
pub inputs: Vec<SimplePublicObjectInputForCreate>,
}Fields
inputs: Vec<SimplePublicObjectInputForCreate>Trait Implementations
Sourceimpl Clone for BatchInputSimplePublicObjectInputForCreate
impl Clone for BatchInputSimplePublicObjectInputForCreate
Sourcefn clone(&self) -> BatchInputSimplePublicObjectInputForCreate
fn clone(&self) -> BatchInputSimplePublicObjectInputForCreate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BatchInputSimplePublicObjectInputForCreate
impl<'de> Deserialize<'de> for BatchInputSimplePublicObjectInputForCreate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchInputSimplePublicObjectInputForCreate
impl JsonSchema for BatchInputSimplePublicObjectInputForCreate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BatchInputSimplePublicObjectInputForCreate
impl PartialEq for BatchInputSimplePublicObjectInputForCreate
Sourcefn eq(&self, other: &BatchInputSimplePublicObjectInputForCreate) -> bool
fn eq(&self, other: &BatchInputSimplePublicObjectInputForCreate) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchInputSimplePublicObjectInputForCreate