pub struct BatchResponseSimplePublicObject {
pub completed_at: DateTime<Utc>,
pub requested_at: Option<DateTime<Utc>>,
pub started_at: DateTime<Utc>,
pub links: Option<HashMap<String, String>>,
pub results: Vec<SimplePublicObject>,
pub status: Status,
}Fields
completed_at: DateTime<Utc>requested_at: Option<DateTime<Utc>>started_at: DateTime<Utc>links: Option<HashMap<String, String>>results: Vec<SimplePublicObject>status: StatusTrait Implementations
Sourceimpl Clone for BatchResponseSimplePublicObject
impl Clone for BatchResponseSimplePublicObject
Sourcefn clone(&self) -> BatchResponseSimplePublicObject
fn clone(&self) -> BatchResponseSimplePublicObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BatchResponseSimplePublicObject
impl<'de> Deserialize<'de> for BatchResponseSimplePublicObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchResponseSimplePublicObject
impl JsonSchema for BatchResponseSimplePublicObject
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BatchResponseSimplePublicObject
impl PartialEq for BatchResponseSimplePublicObject
Sourcefn eq(&self, other: &BatchResponseSimplePublicObject) -> bool
fn eq(&self, other: &BatchResponseSimplePublicObject) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchResponseSimplePublicObject