pub struct BatchResponseSimplePublicObjectWithErrors {
pub completed_at: DateTime<Utc>,
pub num_errors: Option<i32>,
pub requested_at: Option<DateTime<Utc>>,
pub started_at: DateTime<Utc>,
pub links: Option<HashMap<String, String>>,
pub results: Vec<SimplePublicObject>,
pub errors: Option<Vec<StandardError>>,
pub status: Status,
}Fields
completed_at: DateTime<Utc>num_errors: Option<i32>requested_at: Option<DateTime<Utc>>started_at: DateTime<Utc>links: Option<HashMap<String, String>>results: Vec<SimplePublicObject>errors: Option<Vec<StandardError>>status: StatusTrait Implementations
Sourceimpl Clone for BatchResponseSimplePublicObjectWithErrors
impl Clone for BatchResponseSimplePublicObjectWithErrors
Sourcefn clone(&self) -> BatchResponseSimplePublicObjectWithErrors
fn clone(&self) -> BatchResponseSimplePublicObjectWithErrors
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for BatchResponseSimplePublicObjectWithErrors
impl<'de> Deserialize<'de> for BatchResponseSimplePublicObjectWithErrors
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BatchResponseSimplePublicObjectWithErrors
impl JsonSchema for BatchResponseSimplePublicObjectWithErrors
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BatchResponseSimplePublicObjectWithErrors
impl PartialEq for BatchResponseSimplePublicObjectWithErrors
Sourcefn eq(&self, other: &BatchResponseSimplePublicObjectWithErrors) -> bool
fn eq(&self, other: &BatchResponseSimplePublicObjectWithErrors) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchResponseSimplePublicObjectWithErrors