pub struct StandardError {
pub sub_category: Option<String>,
pub context: HashMap<String, Vec<String>>,
pub links: HashMap<String, String>,
pub id: Option<String>,
pub category: String,
pub message: String,
pub errors: Vec<ErrorDetail>,
pub status: String,
}Fields
sub_category: Option<String>context: HashMap<String, Vec<String>>links: HashMap<String, String>id: Option<String>category: Stringmessage: Stringerrors: Vec<ErrorDetail>status: StringTrait Implementations
Sourceimpl Clone for StandardError
impl Clone for StandardError
Sourcefn clone(&self) -> StandardError
fn clone(&self) -> StandardError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StandardError
impl Debug for StandardError
Sourceimpl<'de> Deserialize<'de> for StandardError
impl<'de> Deserialize<'de> for StandardError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for StandardError
impl Display for StandardError
Sourceimpl JsonSchema for StandardError
impl JsonSchema for StandardError
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StandardError
impl PartialEq for StandardError
Sourceimpl Serialize for StandardError
impl Serialize for StandardError
Sourceimpl Tabled for StandardError
impl Tabled for StandardError
impl StructuralPartialEq for StandardError