pub struct ValueWithTimestamp {
pub source_id: Option<String>,
pub source_type: String,
pub source_label: Option<String>,
pub updated_by_user_id: Option<i32>,
pub value: String,
pub timestamp: DateTime<Utc>,
}Fields
source_id: Option<String>source_type: Stringsource_label: Option<String>updated_by_user_id: Option<i32>value: Stringtimestamp: DateTime<Utc>Trait Implementations
Sourceimpl Clone for ValueWithTimestamp
impl Clone for ValueWithTimestamp
Sourcefn clone(&self) -> ValueWithTimestamp
fn clone(&self) -> ValueWithTimestamp
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValueWithTimestamp
impl Debug for ValueWithTimestamp
Sourceimpl<'de> Deserialize<'de> for ValueWithTimestamp
impl<'de> Deserialize<'de> for ValueWithTimestamp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ValueWithTimestamp
impl Display for ValueWithTimestamp
Sourceimpl JsonSchema for ValueWithTimestamp
impl JsonSchema for ValueWithTimestamp
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ValueWithTimestamp
impl PartialEq for ValueWithTimestamp
Sourceimpl Serialize for ValueWithTimestamp
impl Serialize for ValueWithTimestamp
Sourceimpl Tabled for ValueWithTimestamp
impl Tabled for ValueWithTimestamp
impl StructuralPartialEq for ValueWithTimestamp